================
Related projects
================

This is a non-exhaustive list of related, open-source projects that users of orix might
find useful:

- :doc:`pyxem <pyxem:index>`: Python library for multi-dimensional diffraction
  microscopy.
  pyxem depends on orix for handling of crystal orientations.
- :doc:`diffsims <diffsims:index>`: Python library for simulating diffraction.
  diffsims depends on orix for orientation sampling and handling of crystal orientations
  and directions.
- :doc:`kikuchipy <kikuchipy:index>`: Python library for processing and analysis of
  electron backscatter diffraction (EBSD) patterns.
  kikuchipy depends on orix for orientation sampling and handling of crystal
  orientations and directions.
- `MTEX <https://mtex-toolbox.github.io>`_: MATLAB toolbox for analyzing and modelling
  crystallographic textures by means of EBSD or pole figure data.
- :doc:`DefDAP <defdap:index>`: Python package for correlating EBSD and high-resolution
  digital image correlation data.
- `numpy-quaternion <https://github.com/moble/quaternion>`_: Python package that adds a
  built in quaternion data dtype to numpy.
  orix depends on numpy-quaternion for quaternion multiplication.
- `texture <https://github.com/usnistgov/texture>`_: Python scripts for analysis of
  crystallographic texture.
- `pymicro <https://pymicro.readthedocs.io>`_`: Python package to work with material
  microstructures and 3D data sets.
- `DREAM.3D <https://dream3d.io/>`_`: C++ library to reconstruct, instatiate, quantify,
  mesh, handle and visualize multidimensional (3D), multimodal data (mainly EBSD
  orientation data).